/*!
 * OOUI v0.39.3
 * https://www.mediawiki.org/wiki/OOUI
 *
 * Copyright 2011–2020 OOUI Team and other contributors.
 * Released under the MIT license
 * http://oojs.mit-license.org
 *
 * Date: 2020-07-10T06:32:25Z
 */
.oo-ui-icon-arrowNext {
  background-image: url('themes/wikimediaui/images/icons/arrowNext-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowNext-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-arrowNext {
  background-image: url('themes/wikimediaui/images/icons/arrowNext-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowNext-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-arrowNext {
  background-image: url('themes/wikimediaui/images/icons/arrowNext-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowNext-rtl-progressive.svg');
}
.oo-ui-icon-arrowPrevious {
  background-image: url('themes/wikimediaui/images/icons/arrowPrevious-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowPrevious-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-arrowPrevious {
  background-image: url('themes/wikimediaui/images/icons/arrowPrevious-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowPrevious-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-arrowPrevious {
  background-image: url('themes/wikimediaui/images/icons/arrowPrevious-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/arrowPrevious-rtl-progressive.svg');
}
.oo-ui-icon-collapse {
  background-image: url('themes/wikimediaui/images/icons/collapse.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/collapse.svg');
}
.oo-ui-image-invert.oo-ui-icon-collapse {
  background-image: url('themes/wikimediaui/images/icons/collapse-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/collapse-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-collapse {
  background-image: url('themes/wikimediaui/images/icons/collapse-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/collapse-progressive.svg');
}
.oo-ui-icon-downTriangle {
  background-image: url('themes/wikimediaui/images/icons/downTriangle.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/downTriangle.svg');
}
.oo-ui-image-invert.oo-ui-icon-downTriangle {
  background-image: url('themes/wikimediaui/images/icons/downTriangle-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/downTriangle-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-downTriangle {
  background-image: url('themes/wikimediaui/images/icons/downTriangle-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/downTriangle-progressive.svg');
}
.oo-ui-icon-draggable {
  background-image: url('themes/wikimediaui/images/icons/draggable.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/draggable.svg');
}
.oo-ui-image-invert.oo-ui-icon-draggable {
  background-image: url('themes/wikimediaui/images/icons/draggable-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/draggable-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-draggable {
  background-image: url('themes/wikimediaui/images/icons/draggable-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/draggable-progressive.svg');
}
.oo-ui-icon-doubleChevronEnd {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-doubleChevronEnd {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-doubleChevronEnd {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronEnd-rtl-progressive.svg');
}
.oo-ui-icon-doubleChevronStart {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronStart-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronStart-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-doubleChevronStart {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronStart-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronStart-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-doubleChevronStart {
  background-image: url('themes/wikimediaui/images/icons/doubleChevronStart-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/doubleChevronStart-rtl-progressive.svg');
}
.oo-ui-icon-expand {
  background-image: url('themes/wikimediaui/images/icons/expand.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/expand.svg');
}
.oo-ui-image-invert.oo-ui-icon-expand {
  background-image: url('themes/wikimediaui/images/icons/expand-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/expand-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-expand {
  background-image: url('themes/wikimediaui/images/icons/expand-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/expand-progressive.svg');
}
.oo-ui-icon-move {
  background-image: url('themes/wikimediaui/images/icons/move.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/move.svg');
}
.oo-ui-image-invert.oo-ui-icon-move {
  background-image: url('themes/wikimediaui/images/icons/move-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/move-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-move {
  background-image: url('themes/wikimediaui/images/icons/move-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/move-progressive.svg');
}
.oo-ui-icon-next {
  background-image: url('themes/wikimediaui/images/icons/next-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/next-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-next {
  background-image: url('themes/wikimediaui/images/icons/next-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/next-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-next {
  background-image: url('themes/wikimediaui/images/icons/next-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/next-rtl-progressive.svg');
}
.oo-ui-icon-previous {
  background-image: url('themes/wikimediaui/images/icons/previous-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/previous-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-previous {
  background-image: url('themes/wikimediaui/images/icons/previous-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/previous-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-previous {
  background-image: url('themes/wikimediaui/images/icons/previous-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/previous-rtl-progressive.svg');
}
.oo-ui-icon-last {
  background-image: url('themes/wikimediaui/images/icons/moveLast-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveLast-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-last {
  background-image: url('themes/wikimediaui/images/icons/moveLast-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveLast-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-last {
  background-image: url('themes/wikimediaui/images/icons/moveLast-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveLast-rtl-progressive.svg');
}
.oo-ui-icon-first {
  background-image: url('themes/wikimediaui/images/icons/moveFirst-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveFirst-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-first {
  background-image: url('themes/wikimediaui/images/icons/moveFirst-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveFirst-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-first {
  background-image: url('themes/wikimediaui/images/icons/moveFirst-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moveFirst-rtl-progressive.svg');
}
.oo-ui-icon-upTriangle {
  background-image: url('themes/wikimediaui/images/icons/upTriangle.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upTriangle.svg');
}
.oo-ui-image-invert.oo-ui-icon-upTriangle {
  background-image: url('themes/wikimediaui/images/icons/upTriangle-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upTriangle-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-upTriangle {
  background-image: url('themes/wikimediaui/images/icons/upTriangle-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upTriangle-progressive.svg');
}

.oo-ui-icon-article {
  background-image: url('themes/wikimediaui/images/icons/article-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/article-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-article {
  background-image: url('themes/wikimediaui/images/icons/article-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/article-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-article {
  background-image: url('themes/wikimediaui/images/icons/article-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/article-rtl-progressive.svg');
}
.oo-ui-icon-articles {
  background-image: url('themes/wikimediaui/images/icons/articles-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articles-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-articles {
  background-image: url('themes/wikimediaui/images/icons/articles-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articles-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articles {
  background-image: url('themes/wikimediaui/images/icons/articles-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articles-rtl-progressive.svg');
}
.oo-ui-icon-articleAdd {
  background-image: url('themes/wikimediaui/images/icons/articleAdd.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleAdd.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleAdd {
  background-image: url('themes/wikimediaui/images/icons/articleAdd-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleAdd-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleAdd {
  background-image: url('themes/wikimediaui/images/icons/articleAdd-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleAdd-progressive.svg');
}
.oo-ui-icon-articleCheck {
  background-image: url('themes/wikimediaui/images/icons/articleCheck.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleCheck.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleCheck {
  background-image: url('themes/wikimediaui/images/icons/articleCheck-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleCheck-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleCheck {
  background-image: url('themes/wikimediaui/images/icons/articleCheck-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleCheck-progressive.svg');
}
.oo-ui-icon-articleDisambiguation {
  background-image: url('themes/wikimediaui/images/icons/articleDisambiguation-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleDisambiguation-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleDisambiguation {
  background-image: url('themes/wikimediaui/images/icons/articleDisambiguation-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleDisambiguation-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleDisambiguation {
  background-image: url('themes/wikimediaui/images/icons/articleDisambiguation-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleDisambiguation-rtl-progressive.svg');
}
.oo-ui-icon-articleNotFound {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-rtl.svg');
}
/* @noflip */
.oo-ui-icon-articleNotFound:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr.svg');
}
/* @noflip */
.oo-ui-icon-articleNotFound:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleNotFound {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-rtl-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-articleNotFound:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-articleNotFound:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleNotFound {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-rtl-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-articleNotFound:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-articleNotFound:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/articleNotFound-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleNotFound-ltr-progressive.svg');
}
.oo-ui-icon-articleSearch {
  background-image: url('themes/wikimediaui/images/icons/articleSearch.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleSearch.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleSearch {
  background-image: url('themes/wikimediaui/images/icons/articleSearch-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleSearch-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleSearch {
  background-image: url('themes/wikimediaui/images/icons/articleSearch-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleSearch-progressive.svg');
}
.oo-ui-icon-articlesSearch {
  background-image: url('themes/wikimediaui/images/icons/articlesSearch-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articlesSearch-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-articlesSearch {
  background-image: url('themes/wikimediaui/images/icons/articlesSearch-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articlesSearch-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articlesSearch {
  background-image: url('themes/wikimediaui/images/icons/articlesSearch-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articlesSearch-rtl-progressive.svg');
}
.oo-ui-icon-articleRedirect {
  background-image: url('themes/wikimediaui/images/icons/articleRedirect-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleRedirect-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-articleRedirect {
  background-image: url('themes/wikimediaui/images/icons/articleRedirect-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleRedirect-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-articleRedirect {
  background-image: url('themes/wikimediaui/images/icons/articleRedirect-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/articleRedirect-rtl-progressive.svg');
}
.oo-ui-icon-die {
  background-image: url('themes/wikimediaui/images/icons/die.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/die.svg');
}
.oo-ui-image-invert.oo-ui-icon-die {
  background-image: url('themes/wikimediaui/images/icons/die-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/die-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-die {
  background-image: url('themes/wikimediaui/images/icons/die-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/die-progressive.svg');
}
.oo-ui-icon-download {
  background-image: url('themes/wikimediaui/images/icons/download.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/download.svg');
}
.oo-ui-image-invert.oo-ui-icon-download {
  background-image: url('themes/wikimediaui/images/icons/download-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/download-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-download {
  background-image: url('themes/wikimediaui/images/icons/download-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/download-progressive.svg');
}
.oo-ui-icon-folderPlaceholder {
  background-image: url('themes/wikimediaui/images/icons/folderPlaceholder-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/folderPlaceholder-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-folderPlaceholder {
  background-image: url('themes/wikimediaui/images/icons/folderPlaceholder-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/folderPlaceholder-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-folderPlaceholder {
  background-image: url('themes/wikimediaui/images/icons/folderPlaceholder-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/folderPlaceholder-rtl-progressive.svg');
}
.oo-ui-icon-history {
  background-image: url('themes/wikimediaui/images/icons/history.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/history.svg');
}
.oo-ui-image-invert.oo-ui-icon-history {
  background-image: url('themes/wikimediaui/images/icons/history-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/history-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-history {
  background-image: url('themes/wikimediaui/images/icons/history-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/history-progressive.svg');
}
.oo-ui-icon-info {
  background-image: url('themes/wikimediaui/images/icons/info.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/info.svg');
}
/* @noflip */
.oo-ui-icon-info:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb.svg');
}
.oo-ui-image-invert.oo-ui-icon-info {
  background-image: url('themes/wikimediaui/images/icons/info-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/info-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-info:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-info {
  background-image: url('themes/wikimediaui/images/icons/info-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/info-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-info:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-progressive.svg');
}
.oo-ui-icon-infoFilled {
  background-image: url('themes/wikimediaui/images/icons/infoFilled.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/infoFilled.svg');
}
/* @noflip */
.oo-ui-icon-infoFilled:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb.svg');
}
.oo-ui-image-invert.oo-ui-icon-infoFilled {
  background-image: url('themes/wikimediaui/images/icons/infoFilled-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/infoFilled-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-infoFilled:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-infoFilled {
  background-image: url('themes/wikimediaui/images/icons/infoFilled-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/infoFilled-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-infoFilled:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-progressive.svg');
}
.oo-ui-icon-robot {
  background-image: url('themes/wikimediaui/images/icons/robot.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/robot.svg');
}
.oo-ui-image-invert.oo-ui-icon-robot {
  background-image: url('themes/wikimediaui/images/icons/robot-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/robot-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-robot {
  background-image: url('themes/wikimediaui/images/icons/robot-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/robot-progressive.svg');
}
.oo-ui-icon-specialPages {
  background-image: url('themes/wikimediaui/images/icons/specialPages-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialPages-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-specialPages {
  background-image: url('themes/wikimediaui/images/icons/specialPages-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialPages-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-specialPages {
  background-image: url('themes/wikimediaui/images/icons/specialPages-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialPages-rtl-progressive.svg');
}
.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl.svg');
}
.oo-ui-image-destructive.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl-destructive.svg');
}
.oo-ui-image-error.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl-error.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl-error.svg');
}
.oo-ui-image-warning.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl-warning.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl-warning.svg');
}
.oo-ui-image-invert.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tag {
  background-image: url('themes/wikimediaui/images/icons/tag-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tag-rtl-progressive.svg');
}
.oo-ui-icon-upload {
  background-image: url('themes/wikimediaui/images/icons/upload.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upload.svg');
}
.oo-ui-image-invert.oo-ui-icon-upload {
  background-image: url('themes/wikimediaui/images/icons/upload-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upload-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-upload {
  background-image: url('themes/wikimediaui/images/icons/upload-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/upload-progressive.svg');
}
.oo-ui-icon-window {
  background-image: url('themes/wikimediaui/images/icons/window.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/window.svg');
}
.oo-ui-image-invert.oo-ui-icon-window {
  background-image: url('themes/wikimediaui/images/icons/window-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/window-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-window {
  background-image: url('themes/wikimediaui/images/icons/window-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/window-progressive.svg');
}

.oo-ui-icon-alert {
  background-image: url('themes/wikimediaui/images/icons/alert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alert.svg');
}
.oo-ui-image-warning.oo-ui-icon-alert {
  background-image: url('themes/wikimediaui/images/icons/alert-warning.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alert-warning.svg');
}
.oo-ui-image-invert.oo-ui-icon-alert {
  background-image: url('themes/wikimediaui/images/icons/alert-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alert-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-alert {
  background-image: url('themes/wikimediaui/images/icons/alert-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alert-progressive.svg');
}
.oo-ui-icon-bell {
  background-image: url('themes/wikimediaui/images/icons/bell.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bell.svg');
}
.oo-ui-image-invert.oo-ui-icon-bell {
  background-image: url('themes/wikimediaui/images/icons/bell-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bell-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bell {
  background-image: url('themes/wikimediaui/images/icons/bell-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bell-progressive.svg');
}
.oo-ui-icon-bellOutline {
  background-image: url('themes/wikimediaui/images/icons/bellOutline.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bellOutline.svg');
}
.oo-ui-image-invert.oo-ui-icon-bellOutline {
  background-image: url('themes/wikimediaui/images/icons/bellOutline-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bellOutline-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bellOutline {
  background-image: url('themes/wikimediaui/images/icons/bellOutline-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bellOutline-progressive.svg');
}
.oo-ui-icon-error {
  background-image: url('themes/wikimediaui/images/icons/error.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/error.svg');
}
.oo-ui-image-error.oo-ui-icon-error {
  background-image: url('themes/wikimediaui/images/icons/error-error.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/error-error.svg');
}
.oo-ui-image-invert.oo-ui-icon-error {
  background-image: url('themes/wikimediaui/images/icons/error-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/error-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-error {
  background-image: url('themes/wikimediaui/images/icons/error-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/error-progressive.svg');
}
.oo-ui-icon-message {
  background-image: url('themes/wikimediaui/images/icons/message.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/message.svg');
}
.oo-ui-image-invert.oo-ui-icon-message {
  background-image: url('themes/wikimediaui/images/icons/message-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/message-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-message {
  background-image: url('themes/wikimediaui/images/icons/message-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/message-progressive.svg');
}
.oo-ui-icon-notice {
  background-image: url('themes/wikimediaui/images/icons/notice.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notice.svg');
}
.oo-ui-image-invert.oo-ui-icon-notice {
  background-image: url('themes/wikimediaui/images/icons/notice-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notice-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-notice {
  background-image: url('themes/wikimediaui/images/icons/notice-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notice-progressive.svg');
}
.oo-ui-icon-speechBubble {
  background-image: url('themes/wikimediaui/images/icons/speechBubble-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubble-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-speechBubble {
  background-image: url('themes/wikimediaui/images/icons/speechBubble-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubble-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-speechBubble {
  background-image: url('themes/wikimediaui/images/icons/speechBubble-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubble-rtl-progressive.svg');
}
.oo-ui-icon-speechBubbleAdd {
  background-image: url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-speechBubbleAdd {
  background-image: url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-speechBubbleAdd {
  background-image: url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbleAdd-rtl-progressive.svg');
}
.oo-ui-icon-speechBubbles {
  background-image: url('themes/wikimediaui/images/icons/speechBubbles-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbles-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-speechBubbles {
  background-image: url('themes/wikimediaui/images/icons/speechBubbles-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbles-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-speechBubbles {
  background-image: url('themes/wikimediaui/images/icons/speechBubbles-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/speechBubbles-rtl-progressive.svg');
}
.oo-ui-icon-tray {
  background-image: url('themes/wikimediaui/images/icons/tray.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tray.svg');
}
.oo-ui-image-invert.oo-ui-icon-tray {
  background-image: url('themes/wikimediaui/images/icons/tray-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tray-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tray {
  background-image: url('themes/wikimediaui/images/icons/tray-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tray-progressive.svg');
}

.oo-ui-icon-add {
  background-image: url('themes/wikimediaui/images/icons/add.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/add.svg');
}
.oo-ui-image-invert.oo-ui-icon-add {
  background-image: url('themes/wikimediaui/images/icons/add-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/add-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-add {
  background-image: url('themes/wikimediaui/images/icons/add-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/add-progressive.svg');
}
.oo-ui-icon-browser {
  background-image: url('themes/wikimediaui/images/icons/browser-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/browser-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-browser {
  background-image: url('themes/wikimediaui/images/icons/browser-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/browser-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-browser {
  background-image: url('themes/wikimediaui/images/icons/browser-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/browser-rtl-progressive.svg');
}
.oo-ui-icon-cancel {
  background-image: url('themes/wikimediaui/images/icons/cancel.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/cancel.svg');
}
.oo-ui-image-destructive.oo-ui-icon-cancel {
  background-image: url('themes/wikimediaui/images/icons/cancel-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/cancel-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-cancel {
  background-image: url('themes/wikimediaui/images/icons/cancel-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/cancel-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-cancel {
  background-image: url('themes/wikimediaui/images/icons/cancel-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/cancel-progressive.svg');
}
.oo-ui-icon-check {
  background-image: url('themes/wikimediaui/images/icons/check.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/check.svg');
}
.oo-ui-image-destructive.oo-ui-icon-check {
  background-image: url('themes/wikimediaui/images/icons/check-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/check-destructive.svg');
}
.oo-ui-image-success.oo-ui-icon-check {
  background-image: url('themes/wikimediaui/images/icons/check-success.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/check-success.svg');
}
.oo-ui-image-invert.oo-ui-icon-check {
  background-image: url('themes/wikimediaui/images/icons/check-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/check-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-check {
  background-image: url('themes/wikimediaui/images/icons/check-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/check-progressive.svg');
}
.oo-ui-icon-checkAll {
  background-image: url('themes/wikimediaui/images/icons/checkAll.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/checkAll.svg');
}
.oo-ui-image-invert.oo-ui-icon-checkAll {
  background-image: url('themes/wikimediaui/images/icons/checkAll-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/checkAll-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-checkAll {
  background-image: url('themes/wikimediaui/images/icons/checkAll-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/checkAll-progressive.svg');
}
.oo-ui-icon-clear {
  background-image: url('themes/wikimediaui/images/icons/clear.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clear.svg');
}
.oo-ui-image-invert.oo-ui-icon-clear {
  background-image: url('themes/wikimediaui/images/icons/clear-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clear-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-clear {
  background-image: url('themes/wikimediaui/images/icons/clear-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clear-progressive.svg');
}
.oo-ui-icon-clock {
  background-image: url('themes/wikimediaui/images/icons/clock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clock.svg');
}
.oo-ui-image-invert.oo-ui-icon-clock {
  background-image: url('themes/wikimediaui/images/icons/clock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-clock {
  background-image: url('themes/wikimediaui/images/icons/clock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/clock-progressive.svg');
}
.oo-ui-icon-close {
  background-image: url('themes/wikimediaui/images/icons/close.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/close.svg');
}
.oo-ui-image-invert.oo-ui-icon-close {
  background-image: url('themes/wikimediaui/images/icons/close-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/close-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-close {
  background-image: url('themes/wikimediaui/images/icons/close-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/close-progressive.svg');
}
.oo-ui-icon-ellipsis {
  background-image: url('themes/wikimediaui/images/icons/ellipsis.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ellipsis.svg');
}
.oo-ui-image-invert.oo-ui-icon-ellipsis {
  background-image: url('themes/wikimediaui/images/icons/ellipsis-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ellipsis-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-ellipsis {
  background-image: url('themes/wikimediaui/images/icons/ellipsis-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ellipsis-progressive.svg');
}
.oo-ui-icon-feedback {
  background-image: url('themes/wikimediaui/images/icons/feedback-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/feedback-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-feedback {
  background-image: url('themes/wikimediaui/images/icons/feedback-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/feedback-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-feedback {
  background-image: url('themes/wikimediaui/images/icons/feedback-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/feedback-rtl-progressive.svg');
}
.oo-ui-icon-funnel {
  background-image: url('themes/wikimediaui/images/icons/funnel-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/funnel-rtl.svg');
}
.oo-ui-image-destructive.oo-ui-icon-funnel {
  background-image: url('themes/wikimediaui/images/icons/funnel-rtl-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/funnel-rtl-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-funnel {
  background-image: url('themes/wikimediaui/images/icons/funnel-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/funnel-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-funnel {
  background-image: url('themes/wikimediaui/images/icons/funnel-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/funnel-rtl-progressive.svg');
}
.oo-ui-icon-heart {
  background-image: url('themes/wikimediaui/images/icons/heart.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/heart.svg');
}
.oo-ui-image-invert.oo-ui-icon-heart {
  background-image: url('themes/wikimediaui/images/icons/heart-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/heart-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-heart {
  background-image: url('themes/wikimediaui/images/icons/heart-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/heart-progressive.svg');
}
.oo-ui-icon-help {
  background-image: url('themes/wikimediaui/images/icons/help-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-rtl.svg');
}
/* @noflip */
.oo-ui-icon-help:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr.svg');
}
/* @noflip */
.oo-ui-icon-help:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr.svg');
}
.oo-ui-image-invert.oo-ui-icon-help {
  background-image: url('themes/wikimediaui/images/icons/help-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-rtl-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-help:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-help:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-help {
  background-image: url('themes/wikimediaui/images/icons/help-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-rtl-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-help:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-help:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/help-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/help-ltr-progressive.svg');
}
.oo-ui-icon-helpNotice {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-rtl.svg');
}
/* @noflip */
.oo-ui-icon-helpNotice:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr.svg');
}
/* @noflip */
.oo-ui-icon-helpNotice:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr.svg');
}
.oo-ui-image-invert.oo-ui-icon-helpNotice {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-rtl-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-helpNotice:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-helpNotice:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-helpNotice {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-rtl-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-helpNotice:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-helpNotice:lang(yi) {
  background-image: url('themes/wikimediaui/images/icons/helpNotice-ltr-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/helpNotice-ltr-progressive.svg');
}
.oo-ui-icon-home {
  background-image: url('themes/wikimediaui/images/icons/home.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/home.svg');
}
.oo-ui-image-invert.oo-ui-icon-home {
  background-image: url('themes/wikimediaui/images/icons/home-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/home-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-home {
  background-image: url('themes/wikimediaui/images/icons/home-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/home-progressive.svg');
}
.oo-ui-icon-key {
  background-image: url('themes/wikimediaui/images/icons/key.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/key.svg');
}
.oo-ui-image-invert.oo-ui-icon-key {
  background-image: url('themes/wikimediaui/images/icons/key-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/key-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-key {
  background-image: url('themes/wikimediaui/images/icons/key-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/key-progressive.svg');
}
.oo-ui-icon-keyboard {
  background-image: url('themes/wikimediaui/images/icons/keyboard.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/keyboard.svg');
}
.oo-ui-image-invert.oo-ui-icon-keyboard {
  background-image: url('themes/wikimediaui/images/icons/keyboard-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/keyboard-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-keyboard {
  background-image: url('themes/wikimediaui/images/icons/keyboard-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/keyboard-progressive.svg');
}
.oo-ui-icon-lightbulb {
  background-image: url('themes/wikimediaui/images/icons/lightbulb.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb.svg');
}
.oo-ui-image-invert.oo-ui-icon-lightbulb {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-lightbulb {
  background-image: url('themes/wikimediaui/images/icons/lightbulb-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lightbulb-progressive.svg');
}
.oo-ui-icon-logIn {
  background-image: url('themes/wikimediaui/images/icons/logIn-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logIn-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-logIn {
  background-image: url('themes/wikimediaui/images/icons/logIn-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logIn-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-logIn {
  background-image: url('themes/wikimediaui/images/icons/logIn-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logIn-rtl-progressive.svg');
}
.oo-ui-icon-logOut {
  background-image: url('themes/wikimediaui/images/icons/logOut-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logOut-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-logOut {
  background-image: url('themes/wikimediaui/images/icons/logOut-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logOut-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-logOut {
  background-image: url('themes/wikimediaui/images/icons/logOut-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logOut-rtl-progressive.svg');
}
.oo-ui-icon-newWindow {
  background-image: url('themes/wikimediaui/images/icons/newWindow-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newWindow-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-newWindow {
  background-image: url('themes/wikimediaui/images/icons/newWindow-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newWindow-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-newWindow {
  background-image: url('themes/wikimediaui/images/icons/newWindow-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newWindow-rtl-progressive.svg');
}
.oo-ui-icon-pageSettings {
  background-image: url('themes/wikimediaui/images/icons/pageSettings.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pageSettings.svg');
}
.oo-ui-image-invert.oo-ui-icon-pageSettings {
  background-image: url('themes/wikimediaui/images/icons/pageSettings-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pageSettings-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-pageSettings {
  background-image: url('themes/wikimediaui/images/icons/pageSettings-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pageSettings-progressive.svg');
}
.oo-ui-icon-printer {
  background-image: url('themes/wikimediaui/images/icons/printer.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/printer.svg');
}
.oo-ui-image-invert.oo-ui-icon-printer {
  background-image: url('themes/wikimediaui/images/icons/printer-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/printer-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-printer {
  background-image: url('themes/wikimediaui/images/icons/printer-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/printer-progressive.svg');
}
.oo-ui-icon-reload {
  background-image: url('themes/wikimediaui/images/icons/reload.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reload.svg');
}
.oo-ui-image-invert.oo-ui-icon-reload {
  background-image: url('themes/wikimediaui/images/icons/reload-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reload-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-reload {
  background-image: url('themes/wikimediaui/images/icons/reload-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reload-progressive.svg');
}
.oo-ui-icon-search {
  background-image: url('themes/wikimediaui/images/icons/search.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/search.svg');
}
.oo-ui-image-invert.oo-ui-icon-search {
  background-image: url('themes/wikimediaui/images/icons/search-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/search-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-search {
  background-image: url('themes/wikimediaui/images/icons/search-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/search-progressive.svg');
}
.oo-ui-icon-settings {
  background-image: url('themes/wikimediaui/images/icons/settings.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/settings.svg');
}
.oo-ui-image-invert.oo-ui-icon-settings {
  background-image: url('themes/wikimediaui/images/icons/settings-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/settings-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-settings {
  background-image: url('themes/wikimediaui/images/icons/settings-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/settings-progressive.svg');
}
.oo-ui-icon-stopHand {
  background-image: url('themes/wikimediaui/images/icons/stopHand.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stopHand.svg');
}
.oo-ui-image-destructive.oo-ui-icon-stopHand {
  background-image: url('themes/wikimediaui/images/icons/stopHand-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stopHand-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-stopHand {
  background-image: url('themes/wikimediaui/images/icons/stopHand-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stopHand-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-stopHand {
  background-image: url('themes/wikimediaui/images/icons/stopHand-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stopHand-progressive.svg');
}
.oo-ui-icon-subtract {
  background-image: url('themes/wikimediaui/images/icons/subtract.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subtract.svg');
}
.oo-ui-image-destructive.oo-ui-icon-subtract {
  background-image: url('themes/wikimediaui/images/icons/subtract-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subtract-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-subtract {
  background-image: url('themes/wikimediaui/images/icons/subtract-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subtract-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-subtract {
  background-image: url('themes/wikimediaui/images/icons/subtract-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subtract-progressive.svg');
}

.oo-ui-icon-bookmarkOutline {
  background-image: url('themes/wikimediaui/images/icons/bookmarkOutline.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmarkOutline.svg');
}
.oo-ui-image-invert.oo-ui-icon-bookmarkOutline {
  background-image: url('themes/wikimediaui/images/icons/bookmarkOutline-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmarkOutline-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bookmarkOutline {
  background-image: url('themes/wikimediaui/images/icons/bookmarkOutline-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmarkOutline-progressive.svg');
}
.oo-ui-icon-bookmark {
  background-image: url('themes/wikimediaui/images/icons/bookmark.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmark.svg');
}
.oo-ui-image-invert.oo-ui-icon-bookmark {
  background-image: url('themes/wikimediaui/images/icons/bookmark-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmark-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bookmark {
  background-image: url('themes/wikimediaui/images/icons/bookmark-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bookmark-progressive.svg');
}
.oo-ui-icon-block {
  background-image: url('themes/wikimediaui/images/icons/block.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/block.svg');
}
.oo-ui-image-destructive.oo-ui-icon-block {
  background-image: url('themes/wikimediaui/images/icons/block-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/block-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-block {
  background-image: url('themes/wikimediaui/images/icons/block-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/block-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-block {
  background-image: url('themes/wikimediaui/images/icons/block-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/block-progressive.svg');
}
.oo-ui-icon-unBlock {
  background-image: url('themes/wikimediaui/images/icons/unBlock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unBlock.svg');
}
.oo-ui-image-invert.oo-ui-icon-unBlock {
  background-image: url('themes/wikimediaui/images/icons/unBlock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unBlock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-unBlock {
  background-image: url('themes/wikimediaui/images/icons/unBlock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unBlock-progressive.svg');
}
.oo-ui-icon-flag {
  background-image: url('themes/wikimediaui/images/icons/flag-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/flag-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-flag {
  background-image: url('themes/wikimediaui/images/icons/flag-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/flag-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-flag {
  background-image: url('themes/wikimediaui/images/icons/flag-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/flag-rtl-progressive.svg');
}
.oo-ui-icon-unFlag {
  background-image: url('themes/wikimediaui/images/icons/unFlag-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unFlag-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-unFlag {
  background-image: url('themes/wikimediaui/images/icons/unFlag-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unFlag-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-unFlag {
  background-image: url('themes/wikimediaui/images/icons/unFlag-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unFlag-rtl-progressive.svg');
}
.oo-ui-icon-lock {
  background-image: url('themes/wikimediaui/images/icons/lock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lock.svg');
}
.oo-ui-image-destructive.oo-ui-icon-lock {
  background-image: url('themes/wikimediaui/images/icons/lock-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lock-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-lock {
  background-image: url('themes/wikimediaui/images/icons/lock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-lock {
  background-image: url('themes/wikimediaui/images/icons/lock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/lock-progressive.svg');
}
.oo-ui-icon-unLock {
  background-image: url('themes/wikimediaui/images/icons/unLock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLock.svg');
}
.oo-ui-image-destructive.oo-ui-icon-unLock {
  background-image: url('themes/wikimediaui/images/icons/unLock-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLock-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-unLock {
  background-image: url('themes/wikimediaui/images/icons/unLock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-unLock {
  background-image: url('themes/wikimediaui/images/icons/unLock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLock-progressive.svg');
}
.oo-ui-icon-restore {
  background-image: url('themes/wikimediaui/images/icons/restore.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/restore.svg');
}
.oo-ui-image-invert.oo-ui-icon-restore {
  background-image: url('themes/wikimediaui/images/icons/restore-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/restore-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-restore {
  background-image: url('themes/wikimediaui/images/icons/restore-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/restore-progressive.svg');
}
.oo-ui-icon-star {
  background-image: url('themes/wikimediaui/images/icons/star.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/star.svg');
}
.oo-ui-image-invert.oo-ui-icon-star {
  background-image: url('themes/wikimediaui/images/icons/star-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/star-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-star {
  background-image: url('themes/wikimediaui/images/icons/star-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/star-progressive.svg');
}
.oo-ui-icon-halfStar {
  background-image: url('themes/wikimediaui/images/icons/halfStar-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfStar-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-halfStar {
  background-image: url('themes/wikimediaui/images/icons/halfStar-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfStar-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-halfStar {
  background-image: url('themes/wikimediaui/images/icons/halfStar-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfStar-rtl-progressive.svg');
}
.oo-ui-icon-unStar {
  background-image: url('themes/wikimediaui/images/icons/unStar.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unStar.svg');
}
.oo-ui-image-invert.oo-ui-icon-unStar {
  background-image: url('themes/wikimediaui/images/icons/unStar-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unStar-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-unStar {
  background-image: url('themes/wikimediaui/images/icons/unStar-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unStar-progressive.svg');
}
.oo-ui-icon-trash {
  background-image: url('themes/wikimediaui/images/icons/trash.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/trash.svg');
}
.oo-ui-image-destructive.oo-ui-icon-trash {
  background-image: url('themes/wikimediaui/images/icons/trash-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/trash-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-trash {
  background-image: url('themes/wikimediaui/images/icons/trash-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/trash-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-trash {
  background-image: url('themes/wikimediaui/images/icons/trash-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/trash-progressive.svg');
}
.oo-ui-icon-pushPin {
  background-image: url('themes/wikimediaui/images/icons/pushPin.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pushPin.svg');
}
.oo-ui-image-invert.oo-ui-icon-pushPin {
  background-image: url('themes/wikimediaui/images/icons/pushPin-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pushPin-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-pushPin {
  background-image: url('themes/wikimediaui/images/icons/pushPin-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pushPin-progressive.svg');
}
.oo-ui-icon-ongoingConversation {
  background-image: url('themes/wikimediaui/images/icons/ongoingConversation-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ongoingConversation-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-ongoingConversation {
  background-image: url('themes/wikimediaui/images/icons/ongoingConversation-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ongoingConversation-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-ongoingConversation {
  background-image: url('themes/wikimediaui/images/icons/ongoingConversation-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/ongoingConversation-rtl-progressive.svg');
}

.oo-ui-icon-edit {
  background-image: url('themes/wikimediaui/images/icons/edit.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/edit.svg');
}
.oo-ui-image-invert.oo-ui-icon-edit {
  background-image: url('themes/wikimediaui/images/icons/edit-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/edit-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-edit {
  background-image: url('themes/wikimediaui/images/icons/edit-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/edit-progressive.svg');
}
.oo-ui-icon-editLock {
  background-image: url('themes/wikimediaui/images/icons/editLock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editLock.svg');
}
.oo-ui-image-invert.oo-ui-icon-editLock {
  background-image: url('themes/wikimediaui/images/icons/editLock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editLock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-editLock {
  background-image: url('themes/wikimediaui/images/icons/editLock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editLock-progressive.svg');
}
.oo-ui-icon-editUndo {
  background-image: url('themes/wikimediaui/images/icons/editUndo-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editUndo-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-editUndo {
  background-image: url('themes/wikimediaui/images/icons/editUndo-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editUndo-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-editUndo {
  background-image: url('themes/wikimediaui/images/icons/editUndo-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/editUndo-rtl-progressive.svg');
}
.oo-ui-icon-link {
  background-image: url('themes/wikimediaui/images/icons/link.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/link.svg');
}
.oo-ui-image-invert.oo-ui-icon-link {
  background-image: url('themes/wikimediaui/images/icons/link-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/link-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-link {
  background-image: url('themes/wikimediaui/images/icons/link-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/link-progressive.svg');
}
.oo-ui-icon-unLink {
  background-image: url('themes/wikimediaui/images/icons/unLink.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLink.svg');
}
.oo-ui-image-destructive.oo-ui-icon-unLink {
  background-image: url('themes/wikimediaui/images/icons/unLink-destructive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLink-destructive.svg');
}
.oo-ui-image-invert.oo-ui-icon-unLink {
  background-image: url('themes/wikimediaui/images/icons/unLink-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLink-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-unLink {
  background-image: url('themes/wikimediaui/images/icons/unLink-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/unLink-progressive.svg');
}
.oo-ui-icon-linkExternal {
  background-image: url('themes/wikimediaui/images/icons/linkExternal-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkExternal-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-linkExternal {
  background-image: url('themes/wikimediaui/images/icons/linkExternal-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkExternal-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-linkExternal {
  background-image: url('themes/wikimediaui/images/icons/linkExternal-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkExternal-rtl-progressive.svg');
}
.oo-ui-icon-linkSecure {
  background-image: url('themes/wikimediaui/images/icons/linkSecure.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkSecure.svg');
}
.oo-ui-image-invert.oo-ui-icon-linkSecure {
  background-image: url('themes/wikimediaui/images/icons/linkSecure-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkSecure-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-linkSecure {
  background-image: url('themes/wikimediaui/images/icons/linkSecure-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/linkSecure-progressive.svg');
}
.oo-ui-icon-redo {
  background-image: url('themes/wikimediaui/images/icons/redo-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/redo-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-redo {
  background-image: url('themes/wikimediaui/images/icons/redo-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/redo-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-redo {
  background-image: url('themes/wikimediaui/images/icons/redo-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/redo-rtl-progressive.svg');
}
.oo-ui-icon-undo {
  background-image: url('themes/wikimediaui/images/icons/undo-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/undo-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-undo {
  background-image: url('themes/wikimediaui/images/icons/undo-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/undo-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-undo {
  background-image: url('themes/wikimediaui/images/icons/undo-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/undo-rtl-progressive.svg');
}

.oo-ui-icon-bigger {
  background-image: url('themes/wikimediaui/images/icons/bigger.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bigger.svg');
}
.oo-ui-image-invert.oo-ui-icon-bigger {
  background-image: url('themes/wikimediaui/images/icons/bigger-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bigger-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bigger {
  background-image: url('themes/wikimediaui/images/icons/bigger-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bigger-progressive.svg');
}
.oo-ui-icon-smaller {
  background-image: url('themes/wikimediaui/images/icons/smaller.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smaller.svg');
}
.oo-ui-image-invert.oo-ui-icon-smaller {
  background-image: url('themes/wikimediaui/images/icons/smaller-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smaller-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-smaller {
  background-image: url('themes/wikimediaui/images/icons/smaller-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smaller-progressive.svg');
}
.oo-ui-icon-subscript {
  background-image: url('themes/wikimediaui/images/icons/subscript-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subscript-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-subscript {
  background-image: url('themes/wikimediaui/images/icons/subscript-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subscript-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-subscript {
  background-image: url('themes/wikimediaui/images/icons/subscript-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/subscript-rtl-progressive.svg');
}
.oo-ui-icon-superscript {
  background-image: url('themes/wikimediaui/images/icons/superscript-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/superscript-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-superscript {
  background-image: url('themes/wikimediaui/images/icons/superscript-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/superscript-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-superscript {
  background-image: url('themes/wikimediaui/images/icons/superscript-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/superscript-rtl-progressive.svg');
}
.oo-ui-icon-bold {
  background-image: url('themes/wikimediaui/images/icons/bold-a.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-a.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-ain.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-ain.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-te.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-te.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-palochka.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-palochka.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/bold-b.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/bold-f.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/bold-n.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/bold-n.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/bold-n.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/bold-l.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/bold-l.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-dad.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-dad.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/bold-g.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/bold-g.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/bold-armn-to.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-armn-to.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/bold-geor-man.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-geor-man.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/bold-v.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-v.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-be.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-be.svg');
}
/* @noflip */
.oo-ui-icon-bold:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-jeem.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-jeem.svg');
}
.oo-ui-image-invert.oo-ui-icon-bold {
  background-image: url('themes/wikimediaui/images/icons/bold-a-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-a-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-ain-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-ain-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-te-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-te-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-palochka-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-palochka-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/bold-l-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/bold-l-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-dad-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-dad-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/bold-g-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/bold-g-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/bold-armn-to-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-armn-to-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/bold-geor-man-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-geor-man-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/bold-v-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-v-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-be-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-be-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-bold:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-jeem-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-jeem-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bold {
  background-image: url('themes/wikimediaui/images/icons/bold-a-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-a-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-ain-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-ain-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-te-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-te-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-palochka-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-palochka-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/bold-b-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-b-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/bold-f-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-f-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/bold-n-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-n-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/bold-l-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/bold-l-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-l-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-dad-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-dad-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/bold-g-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/bold-g-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-g-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/bold-armn-to-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-armn-to-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/bold-geor-man-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-geor-man-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-zhe-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/bold-v-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-v-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/bold-cyrl-be-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-cyrl-be-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-bold:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/bold-arab-jeem-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bold-arab-jeem-progressive.svg');
}
.oo-ui-icon-highlight {
  background-image: url('themes/wikimediaui/images/icons/highlight.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/highlight.svg');
}
.oo-ui-image-invert.oo-ui-icon-highlight {
  background-image: url('themes/wikimediaui/images/icons/highlight-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/highlight-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-highlight {
  background-image: url('themes/wikimediaui/images/icons/highlight-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/highlight-progressive.svg');
}
.oo-ui-icon-italic {
  background-image: url('themes/wikimediaui/images/icons/italic-a.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-a.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-meem.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-meem.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/italic-i.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/italic-k.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/italic-c.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/italic-c.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/italic-e.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-e.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/italic-d.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-d.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/italic-armn-sha.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-armn-sha.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/italic-s.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-s.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/italic-geor-kan.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-geor-kan.svg');
}
/* @noflip */
.oo-ui-icon-italic:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-teh.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-teh.svg');
}
.oo-ui-image-invert.oo-ui-icon-italic {
  background-image: url('themes/wikimediaui/images/icons/italic-a-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-a-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-meem-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-meem-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/italic-e-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-e-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/italic-d-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-d-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/italic-armn-sha-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-armn-sha-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/italic-s-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-s-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/italic-geor-kan-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-geor-kan-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-italic:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-teh-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-teh-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-italic {
  background-image: url('themes/wikimediaui/images/icons/italic-a-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-a-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ar) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-meem-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-meem-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(cs) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(fr) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(he) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ml) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(pl) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(pt) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(sco) {
  background-image: url('themes/wikimediaui/images/icons/italic-i-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-i-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(be) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ce) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(da) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ky) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(nn) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(no) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(os) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(sv) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ru) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(uk) {
  background-image: url('themes/wikimediaui/images/icons/italic-k-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-k-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(es) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(gl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(it) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(nl) {
  background-image: url('themes/wikimediaui/images/icons/italic-c-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-c-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(eu) {
  background-image: url('themes/wikimediaui/images/icons/italic-e-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-e-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(fa) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-keheh-jeem-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(hu) {
  background-image: url('themes/wikimediaui/images/icons/italic-d-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-d-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(hy) {
  background-image: url('themes/wikimediaui/images/icons/italic-armn-sha-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-armn-sha-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ksh) {
  background-image: url('themes/wikimediaui/images/icons/italic-s-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-s-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ka) {
  background-image: url('themes/wikimediaui/images/icons/italic-geor-kan-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-geor-kan-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-italic:lang(ur) {
  background-image: url('themes/wikimediaui/images/icons/italic-arab-teh-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/italic-arab-teh-progressive.svg');
}
.oo-ui-icon-strikethrough {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-a.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-a.svg');
}
/* @noflip */
.oo-ui-icon-strikethrough:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-s.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-s.svg');
}
/* @noflip */
.oo-ui-icon-strikethrough:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-y.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-y.svg');
}
.oo-ui-image-invert.oo-ui-icon-strikethrough {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-a-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-a-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-strikethrough:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-s-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-s-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-strikethrough:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-y-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-y-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-strikethrough {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-a-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-a-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-strikethrough:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-s-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-s-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-strikethrough:lang(fi) {
  background-image: url('themes/wikimediaui/images/icons/strikethrough-y-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/strikethrough-y-progressive.svg');
}
.oo-ui-icon-underline {
  background-image: url('themes/wikimediaui/images/icons/underline-a.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-a.svg');
}
/* @noflip */
.oo-ui-icon-underline:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/underline-u.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u.svg');
}
/* @noflip */
.oo-ui-icon-underline:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/underline-u.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u.svg');
}
.oo-ui-image-invert.oo-ui-icon-underline {
  background-image: url('themes/wikimediaui/images/icons/underline-a-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-a-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-underline:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/underline-u-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u-invert.svg');
}
/* @noflip */
.oo-ui-image-invert.oo-ui-icon-underline:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/underline-u-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-underline {
  background-image: url('themes/wikimediaui/images/icons/underline-a-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-a-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-underline:lang(en) {
  background-image: url('themes/wikimediaui/images/icons/underline-u-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u-progressive.svg');
}
/* @noflip */
.oo-ui-image-progressive.oo-ui-icon-underline:lang(de) {
  background-image: url('themes/wikimediaui/images/icons/underline-u-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/underline-u-progressive.svg');
}
.oo-ui-icon-textLanguage {
  background-image: url('themes/wikimediaui/images/icons/language.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language.svg');
}
.oo-ui-image-invert.oo-ui-icon-textLanguage {
  background-image: url('themes/wikimediaui/images/icons/language-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textLanguage {
  background-image: url('themes/wikimediaui/images/icons/language-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-progressive.svg');
}
.oo-ui-icon-textDirLTR {
  background-image: url('themes/wikimediaui/images/icons/textDirLTR.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirLTR.svg');
}
.oo-ui-image-invert.oo-ui-icon-textDirLTR {
  background-image: url('themes/wikimediaui/images/icons/textDirLTR-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirLTR-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textDirLTR {
  background-image: url('themes/wikimediaui/images/icons/textDirLTR-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirLTR-progressive.svg');
}
.oo-ui-icon-textDirRTL {
  background-image: url('themes/wikimediaui/images/icons/textDirRTL.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirRTL.svg');
}
.oo-ui-image-invert.oo-ui-icon-textDirRTL {
  background-image: url('themes/wikimediaui/images/icons/textDirRTL-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirRTL-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textDirRTL {
  background-image: url('themes/wikimediaui/images/icons/textDirRTL-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textDirRTL-progressive.svg');
}
.oo-ui-icon-textStyle {
  background-image: url('themes/wikimediaui/images/icons/textStyle.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textStyle.svg');
}
.oo-ui-image-invert.oo-ui-icon-textStyle {
  background-image: url('themes/wikimediaui/images/icons/textStyle-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textStyle-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textStyle {
  background-image: url('themes/wikimediaui/images/icons/textStyle-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textStyle-progressive.svg');
}

.oo-ui-icon-indent {
  background-image: url('themes/wikimediaui/images/icons/indent-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/indent-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-indent {
  background-image: url('themes/wikimediaui/images/icons/indent-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/indent-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-indent {
  background-image: url('themes/wikimediaui/images/icons/indent-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/indent-rtl-progressive.svg');
}
.oo-ui-icon-listBullet {
  background-image: url('themes/wikimediaui/images/icons/listBullet-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listBullet-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-listBullet {
  background-image: url('themes/wikimediaui/images/icons/listBullet-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listBullet-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-listBullet {
  background-image: url('themes/wikimediaui/images/icons/listBullet-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listBullet-rtl-progressive.svg');
}
.oo-ui-icon-listNumbered {
  background-image: url('themes/wikimediaui/images/icons/listNumbered-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listNumbered-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-listNumbered {
  background-image: url('themes/wikimediaui/images/icons/listNumbered-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listNumbered-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-listNumbered {
  background-image: url('themes/wikimediaui/images/icons/listNumbered-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/listNumbered-rtl-progressive.svg');
}
.oo-ui-icon-outdent {
  background-image: url('themes/wikimediaui/images/icons/outdent-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outdent-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-outdent {
  background-image: url('themes/wikimediaui/images/icons/outdent-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outdent-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-outdent {
  background-image: url('themes/wikimediaui/images/icons/outdent-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outdent-rtl-progressive.svg');
}

.oo-ui-icon-alignCenter {
  background-image: url('themes/wikimediaui/images/icons/alignCenter.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignCenter.svg');
}
.oo-ui-image-invert.oo-ui-icon-alignCenter {
  background-image: url('themes/wikimediaui/images/icons/alignCenter-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignCenter-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-alignCenter {
  background-image: url('themes/wikimediaui/images/icons/alignCenter-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignCenter-progressive.svg');
}
.oo-ui-icon-alignLeft {
  background-image: url('themes/wikimediaui/images/icons/alignLeft.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignLeft.svg');
}
.oo-ui-image-invert.oo-ui-icon-alignLeft {
  background-image: url('themes/wikimediaui/images/icons/alignLeft-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignLeft-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-alignLeft {
  background-image: url('themes/wikimediaui/images/icons/alignLeft-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignLeft-progressive.svg');
}
.oo-ui-icon-alignRight {
  background-image: url('themes/wikimediaui/images/icons/alignRight.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignRight.svg');
}
.oo-ui-image-invert.oo-ui-icon-alignRight {
  background-image: url('themes/wikimediaui/images/icons/alignRight-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignRight-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-alignRight {
  background-image: url('themes/wikimediaui/images/icons/alignRight-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/alignRight-progressive.svg');
}
.oo-ui-icon-attachment {
  background-image: url('themes/wikimediaui/images/icons/attachment.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/attachment.svg');
}
.oo-ui-image-invert.oo-ui-icon-attachment {
  background-image: url('themes/wikimediaui/images/icons/attachment-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/attachment-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-attachment {
  background-image: url('themes/wikimediaui/images/icons/attachment-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/attachment-progressive.svg');
}
.oo-ui-icon-calendar {
  background-image: url('themes/wikimediaui/images/icons/calendar.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/calendar.svg');
}
.oo-ui-image-invert.oo-ui-icon-calendar {
  background-image: url('themes/wikimediaui/images/icons/calendar-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/calendar-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-calendar {
  background-image: url('themes/wikimediaui/images/icons/calendar-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/calendar-progressive.svg');
}
.oo-ui-icon-code {
  background-image: url('themes/wikimediaui/images/icons/code.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/code.svg');
}
.oo-ui-image-invert.oo-ui-icon-code {
  background-image: url('themes/wikimediaui/images/icons/code-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/code-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-code {
  background-image: url('themes/wikimediaui/images/icons/code-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/code-progressive.svg');
}
.oo-ui-icon-hieroglyph {
  background-image: url('themes/wikimediaui/images/icons/hieroglyph.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/hieroglyph.svg');
}
.oo-ui-image-invert.oo-ui-icon-hieroglyph {
  background-image: url('themes/wikimediaui/images/icons/hieroglyph-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/hieroglyph-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-hieroglyph {
  background-image: url('themes/wikimediaui/images/icons/hieroglyph-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/hieroglyph-progressive.svg');
}
.oo-ui-icon-imageLayoutBasic {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutBasic.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutBasic.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageLayoutBasic {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutBasic-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutBasic-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageLayoutBasic {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutBasic-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutBasic-progressive.svg');
}
.oo-ui-icon-imageLayoutFrame {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrame.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrame.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageLayoutFrame {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrame-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrame-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageLayoutFrame {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrame-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrame-progressive.svg');
}
.oo-ui-icon-imageLayoutFrameless {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrameless.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrameless.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageLayoutFrameless {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrameless-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrameless-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageLayoutFrameless {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutFrameless-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutFrameless-progressive.svg');
}
.oo-ui-icon-imageLayoutThumbnail {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutThumbnail.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutThumbnail.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageLayoutThumbnail {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutThumbnail-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutThumbnail-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageLayoutThumbnail {
  background-image: url('themes/wikimediaui/images/icons/imageLayoutThumbnail-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLayoutThumbnail-progressive.svg');
}
.oo-ui-icon-labFlask {
  background-image: url('themes/wikimediaui/images/icons/labFlask.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/labFlask.svg');
}
.oo-ui-image-invert.oo-ui-icon-labFlask {
  background-image: url('themes/wikimediaui/images/icons/labFlask-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/labFlask-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-labFlask {
  background-image: url('themes/wikimediaui/images/icons/labFlask-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/labFlask-progressive.svg');
}
.oo-ui-icon-language {
  background-image: url('themes/wikimediaui/images/icons/language.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language.svg');
}
.oo-ui-image-invert.oo-ui-icon-language {
  background-image: url('themes/wikimediaui/images/icons/language-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-language {
  background-image: url('themes/wikimediaui/images/icons/language-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-progressive.svg');
}
.oo-ui-icon-layout {
  background-image: url('themes/wikimediaui/images/icons/layout-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/layout-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-layout {
  background-image: url('themes/wikimediaui/images/icons/layout-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/layout-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-layout {
  background-image: url('themes/wikimediaui/images/icons/layout-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/layout-rtl-progressive.svg');
}
.oo-ui-icon-markup {
  background-image: url('themes/wikimediaui/images/icons/markup.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/markup.svg');
}
.oo-ui-image-invert.oo-ui-icon-markup {
  background-image: url('themes/wikimediaui/images/icons/markup-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/markup-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-markup {
  background-image: url('themes/wikimediaui/images/icons/markup-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/markup-progressive.svg');
}
.oo-ui-icon-mathematics {
  background-image: url('themes/wikimediaui/images/icons/mathematics.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematics.svg');
}
.oo-ui-image-invert.oo-ui-icon-mathematics {
  background-image: url('themes/wikimediaui/images/icons/mathematics-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematics-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mathematics {
  background-image: url('themes/wikimediaui/images/icons/mathematics-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematics-progressive.svg');
}
.oo-ui-icon-mathematicsDisplayBlock {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayBlock.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayBlock.svg');
}
.oo-ui-image-invert.oo-ui-icon-mathematicsDisplayBlock {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayBlock-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayBlock-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mathematicsDisplayBlock {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayBlock-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayBlock-progressive.svg');
}
.oo-ui-icon-mathematicsDisplayDefault {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayDefault.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayDefault.svg');
}
.oo-ui-image-invert.oo-ui-icon-mathematicsDisplayDefault {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayDefault-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayDefault-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mathematicsDisplayDefault {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayDefault-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayDefault-progressive.svg');
}
.oo-ui-icon-mathematicsDisplayInline {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayInline.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayInline.svg');
}
.oo-ui-image-invert.oo-ui-icon-mathematicsDisplayInline {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayInline-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayInline-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mathematicsDisplayInline {
  background-image: url('themes/wikimediaui/images/icons/mathematicsDisplayInline-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mathematicsDisplayInline-progressive.svg');
}
.oo-ui-icon-newline {
  background-image: url('themes/wikimediaui/images/icons/newline-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newline-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-newline {
  background-image: url('themes/wikimediaui/images/icons/newline-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newline-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-newline {
  background-image: url('themes/wikimediaui/images/icons/newline-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newline-rtl-progressive.svg');
}
.oo-ui-icon-noWikiText {
  background-image: url('themes/wikimediaui/images/icons/noWikiText.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/noWikiText.svg');
}
.oo-ui-image-invert.oo-ui-icon-noWikiText {
  background-image: url('themes/wikimediaui/images/icons/noWikiText-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/noWikiText-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-noWikiText {
  background-image: url('themes/wikimediaui/images/icons/noWikiText-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/noWikiText-progressive.svg');
}
.oo-ui-icon-outline {
  background-image: url('themes/wikimediaui/images/icons/outline-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outline-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-outline {
  background-image: url('themes/wikimediaui/images/icons/outline-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outline-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-outline {
  background-image: url('themes/wikimediaui/images/icons/outline-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/outline-rtl-progressive.svg');
}
.oo-ui-icon-puzzle {
  background-image: url('themes/wikimediaui/images/icons/puzzle-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/puzzle-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-puzzle {
  background-image: url('themes/wikimediaui/images/icons/puzzle-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/puzzle-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-puzzle {
  background-image: url('themes/wikimediaui/images/icons/puzzle-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/puzzle-rtl-progressive.svg');
}
.oo-ui-icon-quotes {
  background-image: url('themes/wikimediaui/images/icons/quotes-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/quotes-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-quotes {
  background-image: url('themes/wikimediaui/images/icons/quotes-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/quotes-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-quotes {
  background-image: url('themes/wikimediaui/images/icons/quotes-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/quotes-rtl-progressive.svg');
}
.oo-ui-icon-searchCaseSensitive {
  background-image: url('themes/wikimediaui/images/icons/searchCaseSensitive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchCaseSensitive.svg');
}
.oo-ui-image-invert.oo-ui-icon-searchCaseSensitive {
  background-image: url('themes/wikimediaui/images/icons/searchCaseSensitive-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchCaseSensitive-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-searchCaseSensitive {
  background-image: url('themes/wikimediaui/images/icons/searchCaseSensitive-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchCaseSensitive-progressive.svg');
}
.oo-ui-icon-searchDiacritics {
  background-image: url('themes/wikimediaui/images/icons/searchDiacritics.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchDiacritics.svg');
}
.oo-ui-image-invert.oo-ui-icon-searchDiacritics {
  background-image: url('themes/wikimediaui/images/icons/searchDiacritics-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchDiacritics-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-searchDiacritics {
  background-image: url('themes/wikimediaui/images/icons/searchDiacritics-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchDiacritics-progressive.svg');
}
.oo-ui-icon-searchRegularExpression {
  background-image: url('themes/wikimediaui/images/icons/searchRegularExpression.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchRegularExpression.svg');
}
.oo-ui-image-invert.oo-ui-icon-searchRegularExpression {
  background-image: url('themes/wikimediaui/images/icons/searchRegularExpression-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchRegularExpression-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-searchRegularExpression {
  background-image: url('themes/wikimediaui/images/icons/searchRegularExpression-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/searchRegularExpression-progressive.svg');
}
.oo-ui-icon-signature {
  background-image: url('themes/wikimediaui/images/icons/signature-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/signature-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-signature {
  background-image: url('themes/wikimediaui/images/icons/signature-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/signature-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-signature {
  background-image: url('themes/wikimediaui/images/icons/signature-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/signature-rtl-progressive.svg');
}
.oo-ui-icon-specialCharacter {
  background-image: url('themes/wikimediaui/images/icons/specialCharacter.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialCharacter.svg');
}
.oo-ui-image-invert.oo-ui-icon-specialCharacter {
  background-image: url('themes/wikimediaui/images/icons/specialCharacter-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialCharacter-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-specialCharacter {
  background-image: url('themes/wikimediaui/images/icons/specialCharacter-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/specialCharacter-progressive.svg');
}
.oo-ui-icon-table {
  background-image: url('themes/wikimediaui/images/icons/table.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/table.svg');
}
.oo-ui-image-invert.oo-ui-icon-table {
  background-image: url('themes/wikimediaui/images/icons/table-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/table-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-table {
  background-image: url('themes/wikimediaui/images/icons/table-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/table-progressive.svg');
}
.oo-ui-icon-tableAddColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableAddColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableAddColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnAfter-rtl-progressive.svg');
}
.oo-ui-icon-tableAddColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableAddColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableAddColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddColumnBefore-rtl-progressive.svg');
}
.oo-ui-icon-tableAddRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowAfter.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowAfter.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableAddRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowAfter-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowAfter-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableAddRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowAfter-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowAfter-progressive.svg');
}
.oo-ui-icon-tableAddRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowBefore.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowBefore.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableAddRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowBefore-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowBefore-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableAddRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableAddRowBefore-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableAddRowBefore-progressive.svg');
}
.oo-ui-icon-tableCaption {
  background-image: url('themes/wikimediaui/images/icons/tableCaption.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableCaption.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableCaption {
  background-image: url('themes/wikimediaui/images/icons/tableCaption-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableCaption-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableCaption {
  background-image: url('themes/wikimediaui/images/icons/tableCaption-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableCaption-progressive.svg');
}
.oo-ui-icon-tableMergeCells {
  background-image: url('themes/wikimediaui/images/icons/tableMergeCells.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMergeCells.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableMergeCells {
  background-image: url('themes/wikimediaui/images/icons/tableMergeCells-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMergeCells-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableMergeCells {
  background-image: url('themes/wikimediaui/images/icons/tableMergeCells-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMergeCells-progressive.svg');
}
.oo-ui-icon-tableMoveColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableMoveColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableMoveColumnAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnAfter-rtl-progressive.svg');
}
.oo-ui-icon-tableMoveColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableMoveColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableMoveColumnBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveColumnBefore-rtl-progressive.svg');
}
.oo-ui-icon-tableMoveRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowAfter.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowAfter.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableMoveRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowAfter-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowAfter-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableMoveRowAfter {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowAfter-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowAfter-progressive.svg');
}
.oo-ui-icon-tableMoveRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowBefore.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowBefore.svg');
}
.oo-ui-image-invert.oo-ui-icon-tableMoveRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowBefore-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowBefore-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-tableMoveRowBefore {
  background-image: url('themes/wikimediaui/images/icons/tableMoveRowBefore-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/tableMoveRowBefore-progressive.svg');
}
.oo-ui-icon-templateAdd {
  background-image: url('themes/wikimediaui/images/icons/templateAdd-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/templateAdd-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-templateAdd {
  background-image: url('themes/wikimediaui/images/icons/templateAdd-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/templateAdd-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-templateAdd {
  background-image: url('themes/wikimediaui/images/icons/templateAdd-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/templateAdd-rtl-progressive.svg');
}
.oo-ui-icon-translation {
  background-image: url('themes/wikimediaui/images/icons/language.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language.svg');
}
.oo-ui-image-invert.oo-ui-icon-translation {
  background-image: url('themes/wikimediaui/images/icons/language-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-translation {
  background-image: url('themes/wikimediaui/images/icons/language-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/language-progressive.svg');
}
.oo-ui-icon-wikiText {
  background-image: url('themes/wikimediaui/images/icons/wikiText.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/wikiText.svg');
}
.oo-ui-image-invert.oo-ui-icon-wikiText {
  background-image: url('themes/wikimediaui/images/icons/wikiText-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/wikiText-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-wikiText {
  background-image: url('themes/wikimediaui/images/icons/wikiText-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/wikiText-progressive.svg');
}

.oo-ui-icon-book {
  background-image: url('themes/wikimediaui/images/icons/book-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/book-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-book {
  background-image: url('themes/wikimediaui/images/icons/book-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/book-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-book {
  background-image: url('themes/wikimediaui/images/icons/book-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/book-rtl-progressive.svg');
}
.oo-ui-icon-journal {
  background-image: url('themes/wikimediaui/images/icons/journal-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/journal-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-journal {
  background-image: url('themes/wikimediaui/images/icons/journal-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/journal-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-journal {
  background-image: url('themes/wikimediaui/images/icons/journal-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/journal-rtl-progressive.svg');
}
.oo-ui-icon-newspaper {
  background-image: url('themes/wikimediaui/images/icons/newspaper-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newspaper-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-newspaper {
  background-image: url('themes/wikimediaui/images/icons/newspaper-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newspaper-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-newspaper {
  background-image: url('themes/wikimediaui/images/icons/newspaper-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/newspaper-rtl-progressive.svg');
}
.oo-ui-icon-reference {
  background-image: url('themes/wikimediaui/images/icons/reference.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reference.svg');
}
.oo-ui-image-invert.oo-ui-icon-reference {
  background-image: url('themes/wikimediaui/images/icons/reference-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reference-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-reference {
  background-image: url('themes/wikimediaui/images/icons/reference-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/reference-progressive.svg');
}
.oo-ui-icon-referenceExisting {
  background-image: url('themes/wikimediaui/images/icons/referenceExisting-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/referenceExisting-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-referenceExisting {
  background-image: url('themes/wikimediaui/images/icons/referenceExisting-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/referenceExisting-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-referenceExisting {
  background-image: url('themes/wikimediaui/images/icons/referenceExisting-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/referenceExisting-rtl-progressive.svg');
}
.oo-ui-icon-references {
  background-image: url('themes/wikimediaui/images/icons/references-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/references-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-references {
  background-image: url('themes/wikimediaui/images/icons/references-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/references-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-references {
  background-image: url('themes/wikimediaui/images/icons/references-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/references-rtl-progressive.svg');
}

.oo-ui-icon-camera {
  background-image: url('themes/wikimediaui/images/icons/camera.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/camera.svg');
}
.oo-ui-image-invert.oo-ui-icon-camera {
  background-image: url('themes/wikimediaui/images/icons/camera-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/camera-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-camera {
  background-image: url('themes/wikimediaui/images/icons/camera-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/camera-progressive.svg');
}
.oo-ui-icon-chart {
  background-image: url('themes/wikimediaui/images/icons/chart.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/chart.svg');
}
.oo-ui-image-invert.oo-ui-icon-chart {
  background-image: url('themes/wikimediaui/images/icons/chart-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/chart-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-chart {
  background-image: url('themes/wikimediaui/images/icons/chart-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/chart-progressive.svg');
}
.oo-ui-icon-exitFullscreen {
  background-image: url('themes/wikimediaui/images/icons/exitFullscreen.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/exitFullscreen.svg');
}
.oo-ui-image-invert.oo-ui-icon-exitFullscreen {
  background-image: url('themes/wikimediaui/images/icons/exitFullscreen-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/exitFullscreen-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-exitFullscreen {
  background-image: url('themes/wikimediaui/images/icons/exitFullscreen-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/exitFullscreen-progressive.svg');
}
.oo-ui-icon-fullScreen {
  background-image: url('themes/wikimediaui/images/icons/fullScreen.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/fullScreen.svg');
}
.oo-ui-image-invert.oo-ui-icon-fullScreen {
  background-image: url('themes/wikimediaui/images/icons/fullScreen-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/fullScreen-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-fullScreen {
  background-image: url('themes/wikimediaui/images/icons/fullScreen-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/fullScreen-progressive.svg');
}
.oo-ui-icon-image {
  background-image: url('themes/wikimediaui/images/icons/image.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/image.svg');
}
.oo-ui-image-invert.oo-ui-icon-image {
  background-image: url('themes/wikimediaui/images/icons/image-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/image-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-image {
  background-image: url('themes/wikimediaui/images/icons/image-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/image-progressive.svg');
}
.oo-ui-icon-imageAdd {
  background-image: url('themes/wikimediaui/images/icons/imageAdd-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageAdd-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageAdd {
  background-image: url('themes/wikimediaui/images/icons/imageAdd-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageAdd-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageAdd {
  background-image: url('themes/wikimediaui/images/icons/imageAdd-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageAdd-rtl-progressive.svg');
}
.oo-ui-icon-imageBroken {
  background-image: url('themes/wikimediaui/images/icons/imageBroken.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageBroken.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageBroken {
  background-image: url('themes/wikimediaui/images/icons/imageBroken-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageBroken-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageBroken {
  background-image: url('themes/wikimediaui/images/icons/imageBroken-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageBroken-progressive.svg');
}
.oo-ui-icon-imageLock {
  background-image: url('themes/wikimediaui/images/icons/imageLock-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLock-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageLock {
  background-image: url('themes/wikimediaui/images/icons/imageLock-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLock-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageLock {
  background-image: url('themes/wikimediaui/images/icons/imageLock-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageLock-rtl-progressive.svg');
}
.oo-ui-icon-imageGallery {
  background-image: url('themes/wikimediaui/images/icons/imageGallery.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageGallery.svg');
}
.oo-ui-image-invert.oo-ui-icon-imageGallery {
  background-image: url('themes/wikimediaui/images/icons/imageGallery-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageGallery-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-imageGallery {
  background-image: url('themes/wikimediaui/images/icons/imageGallery-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/imageGallery-progressive.svg');
}
.oo-ui-icon-musicalScore {
  background-image: url('themes/wikimediaui/images/icons/musicalScore.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/musicalScore.svg');
}
.oo-ui-image-invert.oo-ui-icon-musicalScore {
  background-image: url('themes/wikimediaui/images/icons/musicalScore-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/musicalScore-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-musicalScore {
  background-image: url('themes/wikimediaui/images/icons/musicalScore-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/musicalScore-progressive.svg');
}
.oo-ui-icon-pause {
  background-image: url('themes/wikimediaui/images/icons/pause.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pause.svg');
}
.oo-ui-image-invert.oo-ui-icon-pause {
  background-image: url('themes/wikimediaui/images/icons/pause-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pause-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-pause {
  background-image: url('themes/wikimediaui/images/icons/pause-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/pause-progressive.svg');
}
.oo-ui-icon-play {
  background-image: url('themes/wikimediaui/images/icons/play.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/play.svg');
}
.oo-ui-image-invert.oo-ui-icon-play {
  background-image: url('themes/wikimediaui/images/icons/play-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/play-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-play {
  background-image: url('themes/wikimediaui/images/icons/play-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/play-progressive.svg');
}
.oo-ui-icon-stop {
  background-image: url('themes/wikimediaui/images/icons/stop.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stop.svg');
}
.oo-ui-image-invert.oo-ui-icon-stop {
  background-image: url('themes/wikimediaui/images/icons/stop-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stop-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-stop {
  background-image: url('themes/wikimediaui/images/icons/stop-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/stop-progressive.svg');
}
.oo-ui-icon-zoomIn {
  background-image: url('themes/wikimediaui/images/icons/zoomIn.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomIn.svg');
}
.oo-ui-image-invert.oo-ui-icon-zoomIn {
  background-image: url('themes/wikimediaui/images/icons/zoomIn-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomIn-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-zoomIn {
  background-image: url('themes/wikimediaui/images/icons/zoomIn-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomIn-progressive.svg');
}
.oo-ui-icon-zoomOut {
  background-image: url('themes/wikimediaui/images/icons/zoomOut.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomOut.svg');
}
.oo-ui-image-invert.oo-ui-icon-zoomOut {
  background-image: url('themes/wikimediaui/images/icons/zoomOut-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomOut-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-zoomOut {
  background-image: url('themes/wikimediaui/images/icons/zoomOut-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/zoomOut-progressive.svg');
}

.oo-ui-icon-globe {
  background-image: url('themes/wikimediaui/images/icons/globe.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/globe.svg');
}
.oo-ui-image-invert.oo-ui-icon-globe {
  background-image: url('themes/wikimediaui/images/icons/globe-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/globe-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-globe {
  background-image: url('themes/wikimediaui/images/icons/globe-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/globe-progressive.svg');
}
.oo-ui-icon-map {
  background-image: url('themes/wikimediaui/images/icons/map-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/map-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-map {
  background-image: url('themes/wikimediaui/images/icons/map-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/map-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-map {
  background-image: url('themes/wikimediaui/images/icons/map-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/map-rtl-progressive.svg');
}
.oo-ui-icon-mapPin {
  background-image: url('themes/wikimediaui/images/icons/mapPin.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPin.svg');
}
.oo-ui-image-invert.oo-ui-icon-mapPin {
  background-image: url('themes/wikimediaui/images/icons/mapPin-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPin-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mapPin {
  background-image: url('themes/wikimediaui/images/icons/mapPin-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPin-progressive.svg');
}
.oo-ui-icon-mapPinAdd {
  background-image: url('themes/wikimediaui/images/icons/mapPinAdd.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPinAdd.svg');
}
.oo-ui-image-invert.oo-ui-icon-mapPinAdd {
  background-image: url('themes/wikimediaui/images/icons/mapPinAdd-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPinAdd-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mapPinAdd {
  background-image: url('themes/wikimediaui/images/icons/mapPinAdd-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapPinAdd-progressive.svg');
}
.oo-ui-icon-mapTrail {
  background-image: url('themes/wikimediaui/images/icons/mapTrail.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapTrail.svg');
}
.oo-ui-image-invert.oo-ui-icon-mapTrail {
  background-image: url('themes/wikimediaui/images/icons/mapTrail-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapTrail-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-mapTrail {
  background-image: url('themes/wikimediaui/images/icons/mapTrail-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/mapTrail-progressive.svg');
}

.oo-ui-icon-userAdd {
  background-image: url('themes/wikimediaui/images/icons/userAdd-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAdd-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-userAdd {
  background-image: url('themes/wikimediaui/images/icons/userAdd-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAdd-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userAdd {
  background-image: url('themes/wikimediaui/images/icons/userAdd-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAdd-rtl-progressive.svg');
}
.oo-ui-icon-userAnonymous {
  background-image: url('themes/wikimediaui/images/icons/userAnonymous.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAnonymous.svg');
}
.oo-ui-image-invert.oo-ui-icon-userAnonymous {
  background-image: url('themes/wikimediaui/images/icons/userAnonymous-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAnonymous-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userAnonymous {
  background-image: url('themes/wikimediaui/images/icons/userAnonymous-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAnonymous-progressive.svg');
}
.oo-ui-icon-userAvatar {
  background-image: url('themes/wikimediaui/images/icons/userAvatar.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatar.svg');
}
.oo-ui-image-invert.oo-ui-icon-userAvatar {
  background-image: url('themes/wikimediaui/images/icons/userAvatar-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatar-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userAvatar {
  background-image: url('themes/wikimediaui/images/icons/userAvatar-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatar-progressive.svg');
}
.oo-ui-icon-userAvatarOutline {
  background-image: url('themes/wikimediaui/images/icons/userAvatarOutline.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatarOutline.svg');
}
.oo-ui-image-invert.oo-ui-icon-userAvatarOutline {
  background-image: url('themes/wikimediaui/images/icons/userAvatarOutline-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatarOutline-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userAvatarOutline {
  background-image: url('themes/wikimediaui/images/icons/userAvatarOutline-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userAvatarOutline-progressive.svg');
}
.oo-ui-icon-userContributions {
  background-image: url('themes/wikimediaui/images/icons/userContributions-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userContributions-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-userContributions {
  background-image: url('themes/wikimediaui/images/icons/userContributions-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userContributions-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userContributions {
  background-image: url('themes/wikimediaui/images/icons/userContributions-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userContributions-rtl-progressive.svg');
}
.oo-ui-icon-userGroup {
  background-image: url('themes/wikimediaui/images/icons/userGroup-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userGroup-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-userGroup {
  background-image: url('themes/wikimediaui/images/icons/userGroup-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userGroup-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userGroup {
  background-image: url('themes/wikimediaui/images/icons/userGroup-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userGroup-rtl-progressive.svg');
}
.oo-ui-icon-userTalk {
  background-image: url('themes/wikimediaui/images/icons/userTalk-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userTalk-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-userTalk {
  background-image: url('themes/wikimediaui/images/icons/userTalk-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userTalk-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-userTalk {
  background-image: url('themes/wikimediaui/images/icons/userTalk-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/userTalk-rtl-progressive.svg');
}

.oo-ui-icon-menu {
  background-image: url('themes/wikimediaui/images/icons/menu.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/menu.svg');
}
.oo-ui-image-invert.oo-ui-icon-menu {
  background-image: url('themes/wikimediaui/images/icons/menu-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/menu-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-menu {
  background-image: url('themes/wikimediaui/images/icons/menu-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/menu-progressive.svg');
}
.oo-ui-icon-recentChanges {
  background-image: url('themes/wikimediaui/images/icons/recentChanges-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/recentChanges-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-recentChanges {
  background-image: url('themes/wikimediaui/images/icons/recentChanges-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/recentChanges-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-recentChanges {
  background-image: url('themes/wikimediaui/images/icons/recentChanges-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/recentChanges-rtl-progressive.svg');
}
.oo-ui-icon-textFlow {
  background-image: url('themes/wikimediaui/images/icons/textFlow-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textFlow-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-textFlow {
  background-image: url('themes/wikimediaui/images/icons/textFlow-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textFlow-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textFlow {
  background-image: url('themes/wikimediaui/images/icons/textFlow-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textFlow-rtl-progressive.svg');
}
.oo-ui-icon-textSummary {
  background-image: url('themes/wikimediaui/images/icons/textSummary-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textSummary-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-textSummary {
  background-image: url('themes/wikimediaui/images/icons/textSummary-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textSummary-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-textSummary {
  background-image: url('themes/wikimediaui/images/icons/textSummary-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/textSummary-rtl-progressive.svg');
}
.oo-ui-icon-viewCompact {
  background-image: url('themes/wikimediaui/images/icons/viewCompact.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewCompact.svg');
}
.oo-ui-image-invert.oo-ui-icon-viewCompact {
  background-image: url('themes/wikimediaui/images/icons/viewCompact-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewCompact-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-viewCompact {
  background-image: url('themes/wikimediaui/images/icons/viewCompact-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewCompact-progressive.svg');
}
.oo-ui-icon-viewDetails {
  background-image: url('themes/wikimediaui/images/icons/viewDetails-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewDetails-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-viewDetails {
  background-image: url('themes/wikimediaui/images/icons/viewDetails-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewDetails-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-viewDetails {
  background-image: url('themes/wikimediaui/images/icons/viewDetails-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/viewDetails-rtl-progressive.svg');
}

.oo-ui-icon-bright {
  background-image: url('themes/wikimediaui/images/icons/bright.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bright.svg');
}
.oo-ui-image-invert.oo-ui-icon-bright {
  background-image: url('themes/wikimediaui/images/icons/bright-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bright-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-bright {
  background-image: url('themes/wikimediaui/images/icons/bright-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/bright-progressive.svg');
}
.oo-ui-icon-halfBright {
  background-image: url('themes/wikimediaui/images/icons/halfBright-rtl.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfBright-rtl.svg');
}
.oo-ui-image-invert.oo-ui-icon-halfBright {
  background-image: url('themes/wikimediaui/images/icons/halfBright-rtl-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfBright-rtl-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-halfBright {
  background-image: url('themes/wikimediaui/images/icons/halfBright-rtl-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/halfBright-rtl-progressive.svg');
}
.oo-ui-icon-notBright {
  background-image: url('themes/wikimediaui/images/icons/notBright.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notBright.svg');
}
.oo-ui-image-invert.oo-ui-icon-notBright {
  background-image: url('themes/wikimediaui/images/icons/notBright-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notBright-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-notBright {
  background-image: url('themes/wikimediaui/images/icons/notBright-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/notBright-progressive.svg');
}
.oo-ui-icon-eye {
  background-image: url('themes/wikimediaui/images/icons/eye.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eye.svg');
}
.oo-ui-image-invert.oo-ui-icon-eye {
  background-image: url('themes/wikimediaui/images/icons/eye-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eye-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-eye {
  background-image: url('themes/wikimediaui/images/icons/eye-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eye-progressive.svg');
}
.oo-ui-icon-eyeClosed {
  background-image: url('themes/wikimediaui/images/icons/eyeClosed.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eyeClosed.svg');
}
.oo-ui-image-invert.oo-ui-icon-eyeClosed {
  background-image: url('themes/wikimediaui/images/icons/eyeClosed-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eyeClosed-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-eyeClosed {
  background-image: url('themes/wikimediaui/images/icons/eyeClosed-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/eyeClosed-progressive.svg');
}
.oo-ui-icon-moon {
  background-image: url('themes/wikimediaui/images/icons/moon.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moon.svg');
}
.oo-ui-image-invert.oo-ui-icon-moon {
  background-image: url('themes/wikimediaui/images/icons/moon-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moon-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-moon {
  background-image: url('themes/wikimediaui/images/icons/moon-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/moon-progressive.svg');
}
.oo-ui-icon-largerText {
  background-image: url('themes/wikimediaui/images/icons/largerText.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/largerText.svg');
}
.oo-ui-image-invert.oo-ui-icon-largerText {
  background-image: url('themes/wikimediaui/images/icons/largerText-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/largerText-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-largerText {
  background-image: url('themes/wikimediaui/images/icons/largerText-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/largerText-progressive.svg');
}
.oo-ui-icon-smallerText {
  background-image: url('themes/wikimediaui/images/icons/smallerText.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smallerText.svg');
}
.oo-ui-image-invert.oo-ui-icon-smallerText {
  background-image: url('themes/wikimediaui/images/icons/smallerText-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smallerText-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-smallerText {
  background-image: url('themes/wikimediaui/images/icons/smallerText-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/smallerText-progressive.svg');
}
.oo-ui-icon-visionSimulator {
  background-image: url('themes/wikimediaui/images/icons/visionSimulator.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/visionSimulator.svg');
}
.oo-ui-image-invert.oo-ui-icon-visionSimulator {
  background-image: url('themes/wikimediaui/images/icons/visionSimulator-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/visionSimulator-invert.svg');
}
.oo-ui-image-progressive.oo-ui-icon-visionSimulator {
  background-image: url('themes/wikimediaui/images/icons/visionSimulator-progressive.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/visionSimulator-progressive.svg');
}

.oo-ui-icon-logoCC {
  background-image: url('themes/wikimediaui/images/icons/logo-CC.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-CC.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoCC {
  background-image: url('themes/wikimediaui/images/icons/logo-CC-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-CC-invert.svg');
}
.oo-ui-icon-logoWikidata {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikidata.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikidata.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoWikidata {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikidata-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikidata-invert.svg');
}
.oo-ui-icon-logoWikimedia {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoWikimedia {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia-invert.svg');
}
.oo-ui-icon-logoWikimediaCommons {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia-Commons.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia-Commons.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoWikimediaCommons {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia-Commons-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia-Commons-invert.svg');
}
.oo-ui-icon-logoWikimediaDiscovery {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia-Discovery.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia-Discovery.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoWikimediaDiscovery {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikimedia-Discovery-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikimedia-Discovery-invert.svg');
}
.oo-ui-icon-logoWikipedia {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikipedia.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikipedia.svg');
}
.oo-ui-image-invert.oo-ui-icon-logoWikipedia {
  background-image: url('themes/wikimediaui/images/icons/logo-Wikipedia-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/icons/logo-Wikipedia-invert.svg');
}

.oo-ui-indicator-clear {
  background-image: url('themes/wikimediaui/images/indicators/clear.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/clear.svg');
}
.oo-ui-image-invert.oo-ui-indicator-clear {
  background-image: url('themes/wikimediaui/images/indicators/clear-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/clear-invert.svg');
}
.oo-ui-indicator-up {
  background-image: url('themes/wikimediaui/images/indicators/up.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/up.svg');
}
.oo-ui-image-invert.oo-ui-indicator-up {
  background-image: url('themes/wikimediaui/images/indicators/up-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/up-invert.svg');
}
.oo-ui-indicator-down {
  background-image: url('themes/wikimediaui/images/indicators/down.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/down.svg');
}
.oo-ui-image-invert.oo-ui-indicator-down {
  background-image: url('themes/wikimediaui/images/indicators/down-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/down-invert.svg');
}
.oo-ui-indicator-required {
  background-image: url('themes/wikimediaui/images/indicators/required.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/required.svg');
}
.oo-ui-image-invert.oo-ui-indicator-required {
  background-image: url('themes/wikimediaui/images/indicators/required-invert.png');
  background-image: linear-gradient(transparent, transparent), /* @embed */ url('themes/wikimediaui/images/indicators/required-invert.svg');
}
